<?php
/**
 * AutoAlias functions
 *
 * @package autoalias2
 * @version 2.0.2
 * @author Trustmaster
 * @copyright (c) 2010 Vladimir Sibirov
 * @license BSD
 */

defined('SED_CODE') or die('Wrong URL');

/**
 * Converts a title into an alias
 *
 * @param string $title Title
 * @param int $id Page ID
 * @param bool $duplicate TRUE if duplicate alias was previously detected
 * @return string 
 */
function autoalias2_convert($title, $id = 0, $duplicate = false)
{
	global $cfg, $sed_translit;
	
	if($cfg['plugin']['autoalias2']['translit'] && is_array($sed_translit))
	{
		$title = strtr($title, $sed_translit);
	}
	$title = preg_replace('#[^\p{L}0-9\-_ ]#u', '', $title);
	$title = str_replace(' ', $cfg['plugin']['autoalias2']['sep'], $title);

	if ($cfg['plugin']['autoalias2']['lowercase'])
	{
		$title = mb_strtolower($title);
	}

	if ($cfg['plugin']['autoalias2']['prepend_id'] && !empty($id))
	{
		$title = $id . $cfg['plugin']['autoalias2']['sep'] . $title;
	}
	elseif ($duplicate)
	{
		switch ($cfg['plugin']['autoalias2']['on_duplicate'])
		{
			case 'ID':
				if (!empty($id))
				{
					$title .= $cfg['plugin']['autoalias2']['sep'] . $id;
					break;
				}
			default:
				$title .= $cfg['plugin']['autoalias2']['sep'] . rand(2, 99);
				break;
		}
	}

	return $title;
}

/**
 * Updates an alias for a specific page
 *
 * @param string $title Page title
 * @param int $id Page ID
 */
function autoalias2_update($title, $id)
{
	global $cfg, $db_pages;
	$duplicate = false;
	do
	{
		$alias = autoalias2_convert($title, $id, $duplicate);
		if (!$cfg['plugin']['autoalias2']['prepend_id']
			&& sed_sql_result(sed_sql_query("SELECT COUNT(*) FROM $db_pages
				WHERE page_alias = '$alias' AND page_id != $id"), 0, 0) > 0)
		{
			$duplicate = true;
		}
		else
		{
			sed_sql_query("UPDATE $db_pages SET page_alias = '$alias' WHERE page_id = $id");
			$duplicate = false;
		}
	}
	while ($duplicate && !$cfg['plugin']['autoalias2']['prepend_id']);
}

?>
